
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.014.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28",
    "Test::More" => 0
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28",
    "perl" => "v5.10.0"
  },
  "dist_abstract" => "Client for Azure Blob Storage",
  "dist_author" => [
    "Junnama Noda <junnama\@alfasado.jp>"
  ],
  "dist_name" => "Net-Azure-StorageClient",
  "dist_version" => "0.6",
  "license" => "perl",
  "module_name" => "Net::Azure::StorageClient",
  "recursive_test_files" => 1,
  "requires" => {
    "Digest::MD5" => 0,
    "Digest::SHA" => 0,
    "Encode" => 0,
    "File::Basename" => 0,
    "File::Find" => 0,
    "File::Path" => 0,
    "File::Spec" => 0,
    "HTTP::Date" => 0,
    "LWP::UserAgent" => 0,
    "MIME::Base64" => 0,
    "Thread::Semaphore" => 0,
    "URI::QueryParam" => 0,
    "XML::Simple" => 0,
    "namespace::clean" => 0,
    "parent" => 0,
    "perl" => "v5.10.0",
    "strict" => 0,
    "threads" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => 0,
    "perl" => "v5.10.0"
  }
);


my %fallback_build_requires = (
  "ExtUtils::MakeMaker" => 0,
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "Test::More" => 0,
  "perl" => "v5.10.0"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
